==> mgb-0.5.4.4-de.zip: header.php <==
<?
	/*
	MGB 0.5.4.4
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include ("settings.php");
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $settings['hpname']; ?> - powered by MGB 0.5.4.4 OpenSource Guestbook</title>
<meta name="author" content="<? echo $settings['autor']; ?>">
<meta name="keywords" content="<? echo $settings['keywords']; ?>">
<meta name="description" content="<? echo $settings['description']; ?>">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="copyright" content="MGB 0.5.4.4  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="robots" content="index,nofollow">
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<?php
         echo $refresh;
         echo $css;
?>
<script type="text/javascript" src="addsmilies.js"></script>
</head>
<?php
	if($settings['hintergrundbild'])
         	{
                 $hintergrundbild=" style='background-image:url(".$settings['hintergrundbild'].");'";
                 }
?>
<body<?php echo $hintergrundbild; ?>>

==> mgb-0.5.4.7-de.zip: header.php <==
<?
	/*
	MGB 0.5.4.7
	Copyright (C) 2004 - 2007  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

        require ("settings.php");
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title><?php echo $settings['hpname']; ?> - powered by MGB 0.5.4.7 OpenSource Guestbook</title>
<meta name="author" content="<? echo $settings['autor']; ?>">
<meta name="keywords" content="<? echo $settings['keywords']; ?>">
<meta name="description" content="<? echo $settings['description']; ?>">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="copyright" content="MGB 0.5.4.7  Copyright 2004-2007 by mopzz -- http://www.m-gb.org/">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="robots" content="index,nofollow">
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<?php
         echo $refresh;
         echo $css;
?>
<script type="text/javascript" src="addsmilies.js"></script>
</head>
<?php
	if($settings['hintergrundbild'])
         	{
                $hintergrundbild=" style='background-image:url(".$settings['hintergrundbild'].");'";
                }
?>
<body<?php echo $hintergrundbild; ?>>
